# Welcome to the documentation for **aeon**

<br>

- Framework for time series tasks such as forecasting and classification.
- Extends the scikit-learn interface, allowing for ease of use for familiar users.
- Efficient implementation of time series algorithms using numba.
- Interfaces with other time series packages to provide a single framework for algorithm comparison.
- Uses a system of optional dependencies to allow easy installation of basic functionality.

<br>

::::{grid} 1 2 2 2
:gutter: 3

:::{grid-item-card}
:img-top: examples/img/forecasting2.png
:text-align: center

Forecasting

^^^

Get started with time series forecasting.

+++

```{button-ref} get_started
:color: primary
:click-parent:
:expand:

Forecasting
```

:::

:::{grid-item-card}
:img-top: examples/img/tsc.png
:text-align: center

Classification

^^^

Get started with time series classification.

+++

```{button-ref} users
:color: primary
:click-parent:
:expand:

Classification
```

:::

:::{grid-item-card}
:img-top: examples/img/tser.png
:text-align: center

Regression

^^^

Get started with time series extrinsic regression.

+++

```{button-ref} installation
:color: primary
:click-parent:
:expand:

Regression
```

:::

:::{grid-item-card}
:img-top: examples/img/tscl.png
:text-align: center

Clustering

^^^

Get started with time series clustering.

+++

```{button-ref} api_reference
:color: primary
:click-parent:
:expand:

Clustering
```

:::

:::{grid-item-card}
:img-top: examples/img/transformation.png
:text-align: center

Transformations

^^^

Get started with time series transformations.

+++

```{button-ref} get_involved
:color: primary
:click-parent:
:expand:

Transformations
```

:::

::::

## Community Channels

**GitHub**: [github.com/aeon-toolkit/aeon](https://github.com/aeon-toolkit/aeon)

**Slack**: [aeon Slack](https://join.slack.com/t/aeon-toolkit/shared_invite/zt-1plkevy4x-vAg1dAUXcuoR38FjY9nxzg)

**Twitter**: link

**LinkedIn**: [linkedin/aeon-toolkit](https://www.linkedin.com/company/aeon-toolkit)


```{toctree}
:maxdepth: 1
:hidden:

installation
get_started
api_reference
examples
get_involved
users
developers
about
```
